<?php 
namespace Elementor; // Custom widgets must be defined in the Elementor namespace
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly (security measure)

/**
 * Widget Name: Fun facts 
 */
class Bigger_Member_Team2 extends Widget_Base{

 	// The get_name() method is a simple one, you just need to return a widget name that will be used in the code.
	public function get_name() {
		return 'bigger-member-team2';
	}

	// The get_title() method, which again, is a very simple one, you need to return the widget title that will be displayed as the widget label.
	public function get_title() {
		return __( 'Bigger Member Team 2', 'bigger' );
	}

	// The get_icon() method, is an optional but recommended method, it lets you set the widget icon. you can use any of the eicon or font-awesome icons, simply return the class name as a string.
	public function get_icon() {
		return 'eicon-person';
	}

	// The get_categories method, lets you set the category of the widget, return the category name as a string.
	public function get_categories() {
		return [ 'category_bigger' ];
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Team Content', 'bigger' ),
			]
		);

		$this->add_control(
	       'member_image',
	        [
	           'label' => esc_html__( 'Member Image', 'bigger' ),
	           'type'  => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
			  	],
		    ]
	    );

	    $this->add_control(
		    'member_name',
	      	[
	          'label' => esc_html__( 'Member Name', 'bigger' ),
	          'type'  => Controls_Manager::TEXTAREA,
	          'default' => esc_html__( 'Jonathan Morgan', 'bigger' ),
	    	]
	    );

        $this->add_control(
            'align_image_h',
            [
                'label' => esc_html__( 'Align Member Image', 'bigger' ),
                'type'  => Controls_Manager::SELECT,
				'default' => 'right',
				'options' => [
					'right' =>  __( 'Left', 'bigger' ),
					'left' =>  __( 'Right', 'bigger' ),
				],
            ]
        );

		$repeater = new Repeater();

	    $repeater->add_control(
	      	'title',
		    [
		        'label'   => esc_html__( 'Social Name', 'bigger' ),
		        'type'    => Controls_Manager::TEXT,
		        'default' => esc_html__( 'Facebook', 'bigger' ),
		    ]
	    );

		$repeater->add_control(
            'social_link',
            [
                'label' => esc_html__( 'Social Link', 'bigger' ),
                'type'  => Controls_Manager::URL,
				'placeholder' => __( 'https://www.facebook.com/bigger', 'bigger' ),
            ]
        );

        $repeater->add_control(
            'social_icon',
            [
                'label' => esc_html__( 'Social Icon', 'bigger' ),
                'type'  => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fab fa-facebook-f',
					'library' => 'fa-brands',
				],
            ]
        );


		$this->add_control(
		    'social_share',
		    [
		        'label'       => esc_html__( 'Social Share', 'bigger' ),
		        'type'        => Controls_Manager::REPEATER,
		        'show_label'  => true,
		        'default'     => [
		            [
		             	'title'       => esc_html__( 'Facebook', 'bigger' ),
		                'social_link' => esc_html__( 'https://www.facebook.com/', 'bigger' ),
		                'social_icon' => [
		                	'value' => 'fab fa-facebook-f',
							'library' => 'fa-brands',
		                ],
		 
		            ],
		            [
		              	'title'       => esc_html__( 'Twitter', 'bigger' ),
		                'social_link' => esc_html__( 'https://www.twitter.com/', 'bigger' ),
		                'social_icon' => [
		                	'value' => 'fab fa-twitter',
							'library' => 'fa-brands',
		                ],
		 
		            ],
		            [
		              	'title'       => esc_html__( 'Linkedin', 'bigger' ),
		                'social_link' => esc_html__( 'https://www.linkedin.com/', 'bigger' ),
		                'social_icon' => [
		                	'value' => 'fab fa-linkedin-in',
							'library' => 'fa-brands',
		                ],
		            ]
		        ],
		        'fields'      => $repeater->get_controls(),
		        'title_field' => '{{{title}}}',
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_responsive_control(
			'title_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => -10,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-title h6' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-title h6' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
				[
					'name'     => 'title_typography',
					'label'    => esc_html__( 'Typography', 'bigger' ),
					'selector' => '{{WRAPPER}} .team-wrap .team-title h6',
				]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'icon_style',
			[
				'label' => esc_html__( 'Social Icon', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'icon_size',
			[
				'label' => esc_html__( 'Font Size', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => 12,
						'max' => 30,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-social a' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'icon_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => -10,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-social a:not(:last-child)' => 'margin-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-social a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_hover_color',
			[
				'label'     => esc_html__( 'Hover Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .team-wrap .team-social a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$align_image =  $settings['align_image_h'];
		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
			// add old default
			$settings['icon'] = 'fa fa-star';
		}
		$migrated = isset( $settings['__fa4_migrated']['social_icon'] );
		$is_new = ! isset( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
		?>
		
        <div class="team-wrap horizontal">
        	<?php if( $align_image == 'right' ){ ?>
            <div class="team-thumb">
                <img src="<?php echo $settings['member_image']['url'];?>" alt="<?php echo $settings['member_name'];?>">                
            </div>
        	<?php }else{ ?>
        	<div class="team-hover <?php echo esc_attr( $align_image ); ?>">
            	<img src="<?php echo get_template_directory_uri()  . '/images/symbol-hover.png'; ?>">
            </div>
        	<?php } ?>
            <div class="team-info">
            	<div>
	                <div class="team-title">
	                    <?php if ( ! empty( $settings['member_name'] ) ) : ?>
                            <h6><?php echo $settings['member_name'];?></h6>
	                    <?php endif; ?>
	                </div>

	                <?php if ( ! empty( $settings['social_share'] ) ) : ?>
	                    <div class="team-social">
	                        <?php foreach ( $settings['social_share'] as $social ) : ?>
								
								<?php 
									$link_attributes = '';
									if ( ! empty( $social['social_link']['url'] ) ) {
										$this->add_render_attribute( 'link', 'href', $social['social_link']['url'] );
										if ( $social['social_link']['is_external'] ) {
											$this->add_render_attribute( 'link', 'target', '_blank' );
										}

										if ( $social['social_link']['nofollow'] ) {
											$this->add_render_attribute( 'link', 'rel', 'nofollow' );
										}
										$link_attributes = $this->get_render_attribute_string( 'link' );
									}
								?>

	                            <?php if ( $link_attributes ) { ?> <a <?php echo $link_attributes; ?> class="<?php  echo strtolower($social['title']);?>"> <?php } ?>
	                                <?php
										if ( $is_new || $migrated ) {
											Icons_Manager::render_icon( $social['social_icon'], [ 'aria-hidden' => 'true' ] );
										} elseif ( ! empty( $settings['icon'] ) ) { ?>
											<i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i><?php
										}
									?>
	                            <?php if ( $link_attributes ) { ?></a><?php } ?>

	                        <?php endforeach; ?>
	                    </div>  
	                <?php endif; ?>
                </div>
            </div><!-- end .hover content -->
            <?php if( $align_image == 'right' ){ ?>
            
            <div class="team-hover <?php echo esc_attr( $align_image ); ?>">
            	<img src="<?php echo get_template_directory_uri()  . '/images/symbol-hover.png'; ?>">
            </div>

        	<?php }else{ ?>

        	<div class="team-thumb">
                <img src="<?php echo $settings['member_image']['url'];?>" alt="<?php echo $settings['member_name'];?>">                
            </div>

        	<?php } ?>
        </div><!-- end .team wrap -->
	        
	    <?php
	}

}
// After the Bigger_Member_Team2 class is defined, I must register the new widget class with Elementor:
Plugin::instance()->widgets_manager->register_widget_type( new Bigger_Member_Team2() );