<?php 
namespace Elementor; // Custom widgets must be defined in the Elementor namespace
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly (security measure)

/**
 * Widget Name: News Slider
 */
class Bigger_News_Slider extends Widget_Base{

 	// The get_name() method is a simple one, you just need to return a widget name that will be used in the code.
	public function get_name() {
		return 'bigger-news-slider';
	}

	// The get_title() method, which again, is a very simple one, you need to return the widget title that will be displayed as the widget label.
	public function get_title() {
		return esc_html__( 'Bigger News Slider', 'bigger' );
	}

	// The get_icon() method, is an optional but recommended method, it lets you set the widget icon. you can use any of the eicon or font-awesome icons, simply return the class name as a string.
	public function get_icon() {
		return 'eicon-post-slider';
	}

	// The get_categories method, lets you set the category of the widget, return the category name as a string.
	public function get_categories() {
		return [ 'category_bigger' ];
	}

	protected function _register_controls() {

		//Content Service box
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'bigger' ),
			]
		);

		$this->add_control(
			'idpost',
			[
				'label' => esc_html__( 'News List', 'bigger' ),
				'type' => Controls_Manager::SELECT2,
				'options' => $this->select_param_news(),
				'multiple' => true,
				'label_block' => true
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'setting_section',
			[
				'label' => esc_html__( 'Setting', 'bigger' ),
				'tab' => Controls_Manager::TAB_SETTINGS,
			]
		);

		$this->add_control(
			'number',
			[
				'label' => esc_html__( 'Slide To Show', 'bigger' ),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'2' => esc_html__( '2', 'bigger' ),
					'3' => esc_html__( '3', 'bigger' ),
					'1' => esc_html__( '1', 'bigger' ),
				],
			]
		);

		$this->add_control(
            'auto',
            [
                'label' => esc_html__('Autoplay ?', 'bigger'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'bigger'),
                'label_off' => esc_html__('No', 'bigger'),
                'return_value' => 'true',
                'default' => 'true',
            ]
        );

        $this->add_control(
			'arrows',
			[
				'label' => esc_html__( 'Arrows Slide ?', 'bigger' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bigger' ),
				'label_off' => esc_html__( 'Hide', 'bigger' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

		$this->add_control(
			'dots',
			[
				'label' => esc_html__( 'Dots Slide ?', 'bigger' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'bigger' ),
				'label_off' => esc_html__( 'Hide', 'bigger' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

		$this->add_control(
            'display_line',
            [
                'label' => esc_html__('Display Line', 'bigger'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'bigger'),
                'label_off' => esc_html__('Hidden', 'bigger'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition'	=>[
                	'display_meta!'	=> ''
                ]
            ]
        );

        $this->add_control(
            'display_meta',
            [
                'label' => esc_html__('Display Meta ?', 'bigger'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'bigger'),
                'label_off' => esc_html__('Hidden', 'bigger'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'image_style_section',
			[
				'label' => esc_html__( 'Image', 'bigger' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
            'img_overlay_color',
            [
                'label' => esc_html__( 'Overlay', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .item-overlay' => 'background-image: linear-gradient(to top, {{VALUE}}, rgba(0, 0, 0, 0));',
                ],
            ]
        );

		$this->end_controls_section();

		$this->start_controls_section(
			'news_slider_style_section',
			[
				'label' => esc_html__( 'Title News', 'bigger' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'spacing_title',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .entry-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'title_news_color',
			[
				'label' => esc_html__( 'Color', 'bigger' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .news-slider .entry-title a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_news_color_hover',
			[
				'label' => esc_html__( 'Hover', 'bigger' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .news-slider .entry-title a:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_news_typography',
				'selector' => '{{WRAPPER}} .news-slider .entry-title a',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'navigation_section',
			[
				'label' => esc_html__( 'Navigation', 'bigger' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'arrow_style',
			[
				'label' => esc_html__( 'Arrow', 'bigger' ),
				'type' => Controls_Manager::HEADING,
				'condition' => [
					'arrows' => 'true'
				]
			]
		);

		$this->add_control(
            'arrow_color',
            [
                'label' => esc_html__( 'Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .news-slider .slick-arrow' => 'color: {{VALUE}};',
                ],
                'condition' => [
					'arrows' => 'true'
				]
            ]
        );

        $this->add_control(
            'arrow_color_hover',
            [
                'label' => esc_html__( 'Hover', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .news-slider .slick-arrow:hover' => 'color: {{VALUE}};',
                ],
                'condition' => [
					'arrows' => 'true'
				]
            ]
        );

        $this->add_control(
            'bg_arrow_color',
            [
                'label' => esc_html__( 'Backgroud Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .news-slider .slick-arrow' => 'background: {{VALUE}};',
                ],
                'condition' => [
					'arrows' => 'true'
				]
            ]
        );

        $this->add_control(
            'arrow_bg_color_hover',
            [
                'label' => esc_html__( 'Hover Backgroud Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .news-slider .slick-arrow:hover' => 'background: {{VALUE}};',
                ],
                'condition' => [
					'arrows' => 'true'
				]
            ]
        );

        $this->add_control(
			'dot_style',
			[
				'label' => esc_html__( 'Dot', 'bigger' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
				'condition' => [
					'dots' => 'true'
				]
			]
		);

		$this->add_control(
            'dot_color',
            [
                'label' => esc_html__( 'Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button:before' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
					'dots' => 'true'
				]
            ]
        );

        $this->add_control(
            'dot_color_active',
            [
                'label' => esc_html__( 'Color Active', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li.slick-active button:before' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
					'dots' => 'true'
				]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'line_section',
			[
				'label' => esc_html__( 'Line', 'bigger' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition'	=> [
					'display_line'	=> 'yes'
				]
			]
		);

		$this->add_responsive_control(
			'spacing_line',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .is-line' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

        $this->add_control(
			'line_width',
			[
				'label' => esc_html__( 'Line Width', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .is-line' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'line_height',
			[
				'label' => esc_html__( 'Line Height', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'default' => [],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 10,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .is-line' => 'height: {{SIZE}}{{UNIT}};',
				],
			]

		);

		$this->add_control(
            'line_color',
            [
                'label' => esc_html__( 'Line Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#b7b7b7',
                'selectors' => [
                    '{{WRAPPER}} .is-line' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'post_meta_style_section',
			[
				'label' => esc_html__( 'Post Meta', 'bigger' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition'	=> [
                	'display_meta'	=> 'yes'
                ]
			]
		);

		$this->add_responsive_control(
			'spacing_meta',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type'  => Controls_Manager::SLIDER,
				'default'  => [],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .meta-post' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
            'post_meta_color',
            [
                'label' => esc_html__( 'Color', 'bigger' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .meta-post span a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'post_meta_typography',
				'selector' => '{{WRAPPER}} .meta-post span a',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<div class="news-slider-wraper">
		<div class="news-slider" data-show="<?php echo esc_attr($settings['number']); ?>" data-auto="<?php echo esc_attr($settings['auto']); ?>" data-dots="<?php echo esc_attr($settings['dots']); ?>" data-arrow="<?php echo esc_attr($settings['arrows']); ?>">
        	<?php

	        $args = array(
	            'post_type' => 'post',
	            'posts_per_page' => -1,
	            'post__in' => $settings['idpost']
	        );
	        $blogpost = new \WP_Query($args);
	        if($blogpost->have_posts()) : while($blogpost->have_posts()) : $blogpost->the_post();
	            $format = get_post_format();
	        ?>
	            <div>
	                <article class="news-item content-area">
	                    <div class="inner-item">
	                        <?php if ( has_post_thumbnail() ) : ?>
                            <div class="thumb-image">
                                <a href="<?php the_permalink(); ?>">
                                    <?php the_post_thumbnail(); ?>
                                    <div class="item-overlay"></div>
                                </a>
                            </div> 
	                        <?php endif; ?>
	                        <div class="inner-post">
	                            <h4 class="entry-title text-light">
	                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
	                            </h4>
	                            <?php if( $settings['display_meta'] ){ ?>
	                            <div class="meta-post">
	                            	<?php if( $settings['display_line'] ){ ?><div class="is-line"></div><?php } ?>
	                            	<?php bigger_post_meta(); ?>
	                            </div>
	                            <?php } ?>
	                        </div>
	                    </div>
	                </article>
	            </div>
	        <?php endwhile; wp_reset_postdata(); endif; ?>
	    </div>
	    </div>
		<?php 
		
	}

	protected function _content_template() {}

	protected function select_param_news() {
	    $args = array(
	        'numberposts' => -1, // 'numberposts' and 'posts_per_page' can be used interchangeably.
	        'post_type'   => 'post'
	    );
	    $posts = get_posts( $args );
	    $cat = array();
	    foreach( $posts as $post ) {
	        if( $post ) {
	            $cat[$post->ID] = $post->post_title;
	        }
	    }
	    return $cat;
	}
}
// After the Bigger_News_Slider class is defined, I must register the new widget class with Elementor:
Plugin::instance()->widgets_manager->register_widget_type( new Bigger_News_Slider() );