<?php 
namespace Elementor; // Custom widgets must be defined in the Elementor namespace
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly (security measure)

/**
 * Widget Name: Fun facts 
 */
class Bigger_Portfolio extends Widget_Base{

 	// The get_name() method is a simple one, you just need to return a widget name that will be used in the code.
	public function get_name() {
		return 'bportfolio';
	}

	// The get_title() method, which again, is a very simple one, you need to return the widget title that will be displayed as the widget label.
	public function get_title() {
		return __( 'Bigger Portfolio Item', 'bigger' );
	}

	// The get_icon() method, is an optional but recommended method, it lets you set the widget icon. you can use any of the eicon or font-awesome icons, simply return the class name as a string.
	public function get_icon() {
		return ' eicon-image-box';
	}

	// The get_categories method, lets you set the category of the widget, return the category name as a string.
	public function get_categories() {
		return [ 'category_bigger' ];
	}

	protected function _register_controls() {

		//Content Service box
		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Content', 'bigger' ),
			]
		);

		$this->add_control(
			'photo', [
				'label' => __( 'Project Photo', 'bigger' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'cate',
			[
				'label' => __( 'Select category', 'bigger' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'options' =>  $this->get_cate(),
				'label_block' => true
			]
		);
		
		$this->add_control(
			'name',
			[
				'label' => __( 'Name Project', 'bigger' ),
				'type' => Controls_Manager::TEXT,
				'placeholder' => __( 'Type your name portfolio here', 'bigger' ),
				'default' => __('Avenger center', 'bigger'),
				'label_block' => true
			]
		);

		$this->add_control(
			'info_project',
			[
				'label' => __( 'Info Project', 'bigger' ),
				'type' => Controls_Manager::WYSIWYG,
				'placeholder' => __( 'Type your info portfolio here', 'bigger' ),
				'default' => __('', 'bigger'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'bigger' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'bigger' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'position',
			[
				'label' => __( 'Image Position', 'bigger' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'top',
				'options' => [
					'top'  => __( 'Top', 'bigger' ),
					'bottom' => __( 'Bottom', 'bigger' ),
				],
			]
		);

		$this->add_control(
			'text_btn',
			[
				'label' => __( 'Text', 'bigger' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'View details', 'bigger' ),
				'placeholder' => __( 'View details', 'bigger' ),
			]
		);

		$this->add_control(
            'display_line',
            [
                'label' => esc_html__('Display Line', 'bigger'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'bigger'),
                'label_off' => esc_html__('Hidden', 'bigger'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

		$this->end_controls_section();

		//Style
		$this->start_controls_section(
			'section_style_layout',
			[
				'label' => esc_html__( 'Content', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'min_height',
			[
				'label'      => esc_html__( 'Min Height', 'bigger' ),
				'type'       => Controls_Manager::SLIDER,
				'range'      => [
					'px' => [
						'min' => 100,
						'max' => 1000,
					],
				],
				'default'    => [],
				'size_units' => [ 'px' ],
				'selectors'  => [
					'{{WRAPPER}} .project-item .p-content' => 'min-height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'content_padding',
			[
				'label'      => esc_html__( 'Padding', 'bigger' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .project-item .p-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'hover_bgcolor',
			[
				'label'     => esc_html__( 'Color Hover', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover .p-content' => 'background-color: {{VALUE}}',
				],
			]
		);
		//Triangle
		$this->add_control(
			'style_triangle',
			[
				'label' => esc_html__( 'Triangle', 'bigger' ),
				'type' => Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);
		$this->add_control(
			'triangle_top_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content.bottom:after' => 'border-bottom-color: {{VALUE}}',
					'{{WRAPPER}} .project-item .p-content.bottom:before' => 'border-bottom-color: {{VALUE}}',
				],
				'condition'	=> [
					'position' => 'top'
				]
			]
		);
		$this->add_control(
			'triangle_top_hcolor',
			[
				'label'     => esc_html__( 'Hover', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover .p-content.bottom:after' => 'border-bottom-color: {{VALUE}}',
					'{{WRAPPER}} .project-item .inner:hover .p-content.bottom:before' => 'border-bottom-color: {{VALUE}}',
				],
				'condition'	=> [
					'position' => 'top'
				]
			]
		);
		$this->add_control(
			'triangle_top_width',
			[
				'label' => __( 'Width', 'industris' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content:after' => 'border-width: {{SIZE}}{{UNIT}}; margin-left: -{{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .project-item .p-content:before' => 'border-width: {{SIZE}}{{UNIT}}; margin-left: -{{SIZE}}{{UNIT}}',
				],
				'condition'	=> [
					'position' => 'top'
				]
			]
		);

		$this->add_control(
			'triangle_bot_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content.top:after' => 'border-top-color: {{VALUE}}',
					'{{WRAPPER}} .project-item .p-content.top:before' => 'border-top-color: {{VALUE}}',
				],
				'condition'	=> [
					'position' => 'bottom'
				]
			]
		);
		$this->add_control(
			'triangle_bot_hcolor',
			[
				'label'     => esc_html__( 'Hover', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover .p-content.top:after' => 'border-top-color: {{VALUE}}',
					'{{WRAPPER}} .project-item .inner:hover .p-content.top:before' => 'border-top-color: {{VALUE}}',
				],
				'condition'	=> [
					'position' => 'bottom'
				]
			]
		);
		$this->add_control(
			'triangle_bot_width',
			[
				'label' => __( 'Width', 'industris' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content:after' => 'border-width: {{SIZE}}{{UNIT}}; margin-left: -{{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .project-item .p-content:before' => 'border-width: {{SIZE}}{{UNIT}}; margin-left: -{{SIZE}}{{UNIT}}',
				],
				'condition'	=> [
					'position' => 'bottom'
				]
			]
		);

		$this->end_controls_section();

		//Title
		$this->start_controls_section(
			'section_style_title',
			[
				'label' => esc_html__( 'Title', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'name!'	=> ''
				]
			]
		);

		$this->add_responsive_control(
			'title_bottom_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .inner h4' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color primary', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content h4 a' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'title_hcolor',
			[
				'label'     => esc_html__( 'Color second', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover h4 a' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .project-item .p-content h4 a',
				
			]
		);

		$this->end_controls_section();

		//Info
		$this->start_controls_section(
			'section_style_info',
			[
				'label' => esc_html__( 'Info', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'info_project!'=> '',
				]
			]
		);
		$this->add_responsive_control(
			'info_bottom_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content ul' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'primary_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content ul li' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'hlight_color',
			[
				'label'     => esc_html__( 'Highlight', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content ul li strong' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'info_typography',
				'selector' => '{{WRAPPER}} .project-item .p-content ul li',
				
			]
		);
		$this->end_controls_section();

		//Cate
		$this->start_controls_section(
			'section_style_cate',
			[
				'label' => esc_html__( 'Category', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'cate!'=> '',
				]
			]
		);
		$this->add_responsive_control(
			'cate_bottom_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content p.p-cate' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'cate_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content p.p-cate span' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'cate_typography',
				'selector' => '{{WRAPPER}} .project-item .p-content p.p-cate span',
				
			]
		);
		$this->end_controls_section();

		//Button
		$this->start_controls_section(
			'section_style_btn',
			[
				'label' => esc_html__( 'Button', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'link[url]!'=> '',
				]
			]
		);
		$this->start_controls_tabs( 'button_tabs' );

		$this->start_controls_tab( 'button_normal', [ 'label' => esc_html__( 'Normal', 'bigger' ) ] );

		$this->add_control(
			'button_text_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content .btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label'     => esc_html__( 'Background Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content .btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'button_hover', [ 'label' => esc_html__( 'Hover', 'bigger' ) ] );

		$this->add_control(
			'button_hover_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover .btn' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_background_color',
			[
				'label'     => esc_html__( 'Background Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .inner:hover .btn' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_typography',
				'selector' => '{{WRAPPER}} .project-item .p-content .btn',
				
			]
		);
		$this->end_controls_section();

		//Line
		$this->start_controls_section(
			'section_style_line',
			[
				'label' => esc_html__( 'Line', 'bigger' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'display_line!'=> '',
				]
			]
		);
		$this->add_responsive_control(
			'line_bottom_space',
			[
				'label' => esc_html__( 'Spacing', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content .is-line' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'line_height',
			[
				'label' => esc_html__( 'Height', 'bigger' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content .is-line' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'line_color',
			[
				'label'     => esc_html__( 'Color', 'bigger' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .project-item .p-content .is-line' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_section();

	}

	private function get_cate() {
		$categories = get_terms('portfolio_cat');
		$cate_name = [];
		if( !empty($categories) ){
	        foreach( (array)$categories as $categorie){
	            $cate_name[$categorie->slug] = $categorie->name;
	        }
	    }
	    return $cate_name;
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<div class="projects style-2">
			<?php 
				$cate_name = '';
				$link_attributes = '';
				if( $settings['cate'] ){
					foreach( $settings['cate'] as $categorie){
			            $cates = get_term_by('slug', $categorie, 'portfolio_cat');
			            $cate_name .= '<span>'.$cates->name.'</span>';
			        }
				}

				if ( ! empty( $settings['link']['url'] ) ) {
					$this->add_render_attribute( 'link', 'href', $settings['link']['url'] );
					$this->add_render_attribute( 'link', 'class', 'pagelink btn' );
					if ( $settings['link']['is_external'] ) {
						$this->add_render_attribute( 'link', 'target', '_blank' );
					}

					if ( $settings['link']['nofollow'] ) {
						$this->add_render_attribute( 'link', 'rel', 'nofollow' );
					}
				}
				$link_attributes = $this->get_render_attribute_string( 'link' );

			?>
				
            <div class="project-item">
                <div class="inner">
                	<?php if( $settings['position'] === 'top' ) { ?>
                	<div class="p-thumb">
	                    <a href="">
	                        <img src="<?php echo esc_attr( $settings['photo']['url'] ); ?>">
	                    </a>
	                </div>
                	<?php } ?>
                    <div class="p-content <?php if( $settings['position'] === 'top' ){ echo 'bottom';}else{ echo 'top'; } ?>">
                    	<?php if( $cate_name ){ ?><p class="p-cate"><?php echo wp_specialchars_decode($cate_name); ?></p><?php } ?>
                    	<?php if( $settings['display_line'] ){ ?><div class="is-line"></div><?php } ?>
                    	<h4><a href=""><?php echo wp_specialchars_decode($settings['name']); ?></a></h4>
                        <?php echo wp_specialchars_decode($settings['info_project']); ?>
                        <?php if( $settings['link']['url'] ){ ?><a <?php echo $link_attributes; ?>><?php echo $settings['text_btn']; ?></a><?php } ?>
                    </div>
                    <?php if( $settings['position'] === 'bottom' ) { ?>
                    <div class="p-thumb">
	                    <a href="">
	                        <img src="<?php echo esc_attr( $settings['photo']['url'] ); ?>">
	                    </a>
	                </div>
                	<?php } ?>
                </div>
            </div>
	    </div>
	    <?php 
	}

	protected function _content_template() {}
}
// After the Bigger_Portfolio class is defined, I must register the new widget class with Elementor:
Plugin::instance()->widgets_manager->register_widget_type( new Bigger_Portfolio() );